@@ -378,7 +378,7 @@ int main(int argc, char* argv[])
 
         /// 終了コードの保存 ///
         char end_code[128];
-        char* lvar =  saphire_get_local_var("RCODE");
+        char* lvar =  saphire_get_global_var("RCODE");
         if(lvar) 
             snprintf(end_code, 128, "%s", lvar);
         else 
@@ -405,7 +405,7 @@ int main(int argc, char* argv[])
         }
 
         /// 終了コードの復帰 ///
-        saphire_set_local_var("RCODE", end_code);
+        saphire_set_global_var("RCODE", end_code);
 
         /// 実行 ///
         if(buf == NULL) {
