@@ -19,6 +19,27 @@
     使い方のサンプルはmain.cを参考にしてください
 */
 
+typedef struct _sObject {
+    string_obj* mName;
+    hash_obj* mGlobals;
+    hash_obj* mHashs;
+    hash_obj* mArrays;
+    hash_obj* mObjects;
+    hash_obj* mClasses;
+
+    struct _sObject* mParent;
+
+    hash_obj* mMethods;
+} sObject;
+
+sObject* sObject_new(char* name, sObject* parent);
+
+sObject* saphire_get_object(char* name);
+    // 引数の名前のオブジェクトを返す
+
+vector_obj* saphire_methods_names(sObject* object);
+    // 引数のオブジェクトのメソッドの一覧を返す
+
 typedef struct {
     int mFd;
     char* mBuffer;
@@ -127,7 +148,7 @@ int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr);
     // 戻り値はプログラムの終了コードだが、0以下だとsaphire内で
     // エラーが起こっている
     // のでgErrMsgをどこかに出力してください。
-    // verboseは実行しているコマンド名を表示するかどうか
+
 BOOL saphire_compile(char* fname, char* out_fname);
     // fnameのファイルをコンパイルしてout_fnameに保存
     // スクリプトファイルを読み込んでコンパイルして
@@ -184,6 +205,9 @@ void saphire_rehash();
     // プログラム補完候補の一覧の再読み込み
     // $PATHから読み込む
     // gSaphireProgCompletions(動的配列型vector_obj*)に文字列型(string_obj*)として入る
+void saphire_rehash2();
+    // プログラム補完候補の一覧の再読み込み
+    // 外部コマンドはりハッシュしない
 
 extern BOOL gKitutukiExit;
         // exit内部コマンドが呼ばれたらTRUEが入る
