@@ -397,7 +397,7 @@ extern hash_obj* gObjects;
 ////////////////////////////////////////////////////////////
 /// from saphire_commands.c
 ////////////////////////////////////////////////////////////
-int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, char* title, BOOL input, BOOL* return_, char* sname, int line, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
+int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, char* title, BOOL input, BOOL* return_, BOOL enable_return, BOOL* break_, BOOL enable_break, char* sname, int line, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
 BOOL vcat_expand_env(string_obj* pipeout, char* env, vector_obj* numbers,char* sname, int line);
 
 ////////////////////////////////////////////////////////////
@@ -430,7 +430,7 @@ extern vector_obj* gStackTraceFName;
 extern vector_obj* gStackTraceLineNum;
     // åե졼εϿ
 
-int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
+int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, BOOL enable_return, BOOL* break_ , BOOL enable_break, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
     // saphire_compile2ǥѥ뤷ѥ̤¹Ԥ롣
 
 int saphire_shell4(char* command, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, sObject* object);
