@@ -2565,7 +2565,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.2.2", 1);
+    setenv("SAPHIRE_VERSION", "3.2.3", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3459,7 +3459,7 @@ sBlock* sBlock_new2(sBlock* block)
     for(i=0; i<vector_size(block->mArgs); i++) {
         vector_add(self->mArgs, STRING_NEW(string_c_str(vector_item(block->mArgs, i))));
     }
-    self->mCount = 0;
+    self->mCount = block->mCount;
 
     return self;
 }
