@@ -2153,10 +2153,11 @@ int saphire_load_obj(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr, vect
 
     /// 実行 ///
     int return_ = FALSE;
+    int break_ = FALSE;
     vector_obj* envs = VECTOR_NEW(10);
     int rcode = run(statments, fname
                 , pipeout, pipein, pipeerr
-                , &return_, parent_blocks, FALSE, envs, NULL, NULL, NULL);
+                , &return_, TRUE, &break_, FALSE, parent_blocks, FALSE, envs, NULL, NULL, NULL);
 
     /// 解放 ///
     close(fd);
