@@ -759,7 +759,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         sClass* klass;
         sInnerCommand* inner_fun;
         char* tmp = strstr(arg0, "->");
-        BOOL class_method = FALSE;
+        BOOL method_class = FALSE;
         if(tmp) {
             char* tmp2 = MALLOC(tmp - arg0 + 1);
             memcpy(tmp2, arg0, tmp-arg0);
@@ -789,7 +789,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             strcpy(tmp3, tmp);
 
             if(strcmp(tmp3, "class") == 0) {
-                class_method = TRUE;
+                method_class = TRUE;
             }
             else {
                 method = hash_item(object2->mMethods, tmp3);
@@ -876,7 +876,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 char buf2[256];
                 snprintf(buf2, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf2);
+                saphire_set_global_var("RCODE", buf2);
 
                 if(*rcode < 0) {
                     string_push_back(gErrMsg, string_c_str(sname_strace));
@@ -893,7 +893,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             }
         }
         /// 継承 ///
-        else if(class_method) {
+        else if(method_class) {
             if(vector_size(argv) >= 2) {
                 char* klassname = string_c_str(vector_item(argv, 1));
 
@@ -950,7 +950,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 char buf2[256];
                 snprintf(buf2, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf2);
+                saphire_set_global_var("RCODE", buf2);
 
                 if(*rcode < 0) {
                     string_push_back(gErrMsg, string_c_str(sname_strace));
@@ -995,7 +995,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 char buf2[256];
                 snprintf(buf2, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf2);
+                saphire_set_global_var("RCODE", buf2);
 
                 if(*rcode < 0) {
                     string_push_back(gErrMsg, string_c_str(sname_strace));
@@ -1111,7 +1111,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             char buf2[256];
             snprintf(buf2, 256, "%d", *rcode);
-            saphire_set_local_var("RCODE", buf2);
+            saphire_set_global_var("RCODE", buf2);
 
             if(*rcode == -1) {
                 string_push_back(gErrMsg, string_c_str(sname_strace));
@@ -1222,7 +1222,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             char buf2[256];
             snprintf(buf2, 256, "%d", *rcode);
-            saphire_set_local_var("RCODE", buf2);
+            saphire_set_global_var("RCODE", buf2);
 
             if(*rcode == -1) {
                 string_push_back(gErrMsg, string_c_str(sname_strace));
@@ -1268,7 +1268,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             char buf[256];
             snprintf(buf, 256, "%d", *rcode);
-            saphire_set_local_var("RCODE", buf);
+            saphire_set_global_var("RCODE", buf);
             if(!r) {
                 return FALSE;
             }
@@ -1308,7 +1308,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             char buf[256];
             snprintf(buf, 256, "%d", *rcode);
-            saphire_set_local_var("RCODE",  buf);
+            saphire_set_global_var("RCODE", buf);
             if(!r) {
                 return FALSE;
             }
@@ -1464,7 +1464,7 @@ void run_wait_cprogs(sStatment* statment, int* rcode, sWFd* pipeout, int last_pr
 
                 char buf[256];
                 snprintf(buf, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf);
+                saphire_set_global_var("RCODE", buf);
             }
             /// 終了した場合 ///
             else if(WIFEXITED(status)) {
@@ -1482,7 +1482,7 @@ void run_wait_cprogs(sStatment* statment, int* rcode, sWFd* pipeout, int last_pr
 
                 char buf[256];
                 snprintf(buf, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf);
+                saphire_set_global_var("RCODE", buf);
             }
             /// シグナルの配送により停止した場合 ///
             else if(WIFSTOPPED(status)) {
@@ -1502,7 +1502,7 @@ void run_wait_cprogs(sStatment* statment, int* rcode, sWFd* pipeout, int last_pr
 
                 char buf[256];
                 snprintf(buf, 256, "%d", *rcode);
-                saphire_set_local_var("RCODE", buf);
+                saphire_set_global_var("RCODE", buf);
 
                 sJob* job = sJob_new();
 
@@ -1925,7 +1925,7 @@ BOOL forground_job(int num)
             int return_code = WEXITSTATUS(status);
             char buf[256];
             snprintf(buf, 256, "%d", return_code);
-            saphire_set_local_var("RCODE", buf);
+            saphire_set_global_var("RCODE", buf);
         }
         /// シグナルの配送により終了した場合 ///
         else if(WIFSIGNALED(status)) {
@@ -1943,7 +1943,7 @@ BOOL forground_job(int num)
             int return_code = WTERMSIG(status) + 128;
             char buf[256];
             snprintf(buf, 256, "%d", return_code);
-            saphire_set_local_var("RCODE", buf);
+            saphire_set_global_var("RCODE", buf);
         }
         /// シグナルの配送によりフォワグランドジョブが停止した場合 ///
         else if(WIFSTOPPED(status)) {
